pub struct GenerateMetadataInstructionArgs {
pub execution_order: Vec<String>,
pub program_id: Pubkey,
pub program_name: String,
pub paraphrase: String,
}Fields
execution_order: Vec<String>program_id: Pubkeyprogram_name: Stringparaphrase: StringTrait Implementations
Sourceimpl BorshDeserialize for GenerateMetadataInstructionArgs
impl BorshDeserialize for GenerateMetadataInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for GenerateMetadataInstructionArgs
impl Clone for GenerateMetadataInstructionArgs
Sourcefn clone(&self) -> GenerateMetadataInstructionArgs
fn clone(&self) -> GenerateMetadataInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for GenerateMetadataInstructionArgs
impl PartialEq for GenerateMetadataInstructionArgs
Sourcefn eq(&self, other: &GenerateMetadataInstructionArgs) -> bool
fn eq(&self, other: &GenerateMetadataInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for GenerateMetadataInstructionArgs
impl StructuralPartialEq for GenerateMetadataInstructionArgs