pub struct ArgumentInfo {
pub name: String,
pub arg_type: ArgumentType,
pub constraints: Vec<ArgumentConstraint>,
pub is_optional: bool,
}Fields
name: Stringarg_type: ArgumentTypeconstraints: Vec<ArgumentConstraint>is_optional: boolTrait Implementations
Sourceimpl BorshDeserialize for ArgumentInfo
impl BorshDeserialize for ArgumentInfo
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ArgumentInfo
impl BorshSerialize for ArgumentInfo
Sourceimpl Clone for ArgumentInfo
impl Clone for ArgumentInfo
Sourcefn clone(&self) -> ArgumentInfo
fn clone(&self) -> ArgumentInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArgumentInfo
impl Debug for ArgumentInfo
Sourceimpl PartialEq for ArgumentInfo
impl PartialEq for ArgumentInfo
impl Eq for ArgumentInfo
impl StructuralPartialEq for ArgumentInfo