pub struct IdlAccount {
pub name: String,
pub fields: Vec<IdlField>,
}Fields
name: Stringfields: Vec<IdlField>Trait Implementations
Sourceimpl BorshDeserialize for IdlAccount
impl BorshDeserialize for IdlAccount
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for IdlAccount
impl BorshSerialize for IdlAccount
Sourceimpl Clone for IdlAccount
impl Clone for IdlAccount
Sourcefn clone(&self) -> IdlAccount
fn clone(&self) -> IdlAccount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdlAccount
impl Debug for IdlAccount
Sourceimpl PartialEq for IdlAccount
impl PartialEq for IdlAccount
impl Eq for IdlAccount
impl StructuralPartialEq for IdlAccount