pub struct IdlData {
pub name: String,
pub version: String,
pub instructions: Vec<IdlInstruction>,
pub accounts: Vec<IdlAccount>,
pub types: Vec<IdlTypeDef>,
pub errors: Vec<IdlError>,
pub constants: Vec<IdlConstant>,
pub events: Vec<IdlEvent>,
}Fields
name: Stringversion: Stringinstructions: Vec<IdlInstruction>accounts: Vec<IdlAccount>types: Vec<IdlTypeDef>errors: Vec<IdlError>constants: Vec<IdlConstant>events: Vec<IdlEvent>Trait Implementations
Sourceimpl BorshDeserialize for IdlData
impl BorshDeserialize for IdlData
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for IdlData
impl BorshSerialize for IdlData
impl Eq for IdlData
impl StructuralPartialEq for IdlData