pub struct IdlEvent {
pub name: String,
pub discriminator: Vec<u8>,
pub fields: Vec<IdlField>,
}Fields
name: Stringdiscriminator: Vec<u8>fields: Vec<IdlField>Trait Implementations
Sourceimpl BorshDeserialize for IdlEvent
impl BorshDeserialize for IdlEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for IdlEvent
impl BorshSerialize for IdlEvent
impl Eq for IdlEvent
impl StructuralPartialEq for IdlEvent