pub struct IdlTypeDef {
pub name: String,
pub kind: String,
pub fields: Vec<String>,
}Fields
name: Stringkind: Stringfields: Vec<String>Trait Implementations
Sourceimpl BorshDeserialize for IdlTypeDef
impl BorshDeserialize for IdlTypeDef
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for IdlTypeDef
impl BorshSerialize for IdlTypeDef
Sourceimpl Clone for IdlTypeDef
impl Clone for IdlTypeDef
Sourcefn clone(&self) -> IdlTypeDef
fn clone(&self) -> IdlTypeDef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdlTypeDef
impl Debug for IdlTypeDef
Sourceimpl PartialEq for IdlTypeDef
impl PartialEq for IdlTypeDef
impl Eq for IdlTypeDef
impl StructuralPartialEq for IdlTypeDef