pub struct InstructionTestCases {
pub instruction_name: String,
pub arguments: Vec<ArgumentInfo>,
pub positive_cases: Vec<TestCase>,
pub negative_cases: Vec<TestCase>,
}Fields
instruction_name: Stringarguments: Vec<ArgumentInfo>positive_cases: Vec<TestCase>negative_cases: Vec<TestCase>Trait Implementations
Sourceimpl BorshDeserialize for InstructionTestCases
impl BorshDeserialize for InstructionTestCases
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for InstructionTestCases
impl Clone for InstructionTestCases
Sourcefn clone(&self) -> InstructionTestCases
fn clone(&self) -> InstructionTestCases
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstructionTestCases
impl Debug for InstructionTestCases
Sourceimpl PartialEq for InstructionTestCases
impl PartialEq for InstructionTestCases
impl Eq for InstructionTestCases
impl StructuralPartialEq for InstructionTestCases