pub struct PdaInit {
pub account_name: String,
pub seeds: Vec<SeedComponent>,
pub program_id: Pubkey,
pub space: Option<u64>,
}Fields
account_name: Stringseeds: Vec<SeedComponent>program_id: Pubkeyspace: Option<u64>Trait Implementations
Sourceimpl BorshDeserialize for PdaInit
impl BorshDeserialize for PdaInit
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for PdaInit
impl BorshSerialize for PdaInit
impl Eq for PdaInit
impl StructuralPartialEq for PdaInit