pub struct SetupRequirement {
pub requirement_type: SetupType,
pub description: String,
pub dependencies: Vec<String>,
}Fields
requirement_type: SetupTypedescription: Stringdependencies: Vec<String>Trait Implementations
Sourceimpl BorshDeserialize for SetupRequirement
impl BorshDeserialize for SetupRequirement
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SetupRequirement
impl BorshSerialize for SetupRequirement
Sourceimpl Clone for SetupRequirement
impl Clone for SetupRequirement
Sourcefn clone(&self) -> SetupRequirement
fn clone(&self) -> SetupRequirement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetupRequirement
impl Debug for SetupRequirement
Sourceimpl PartialEq for SetupRequirement
impl PartialEq for SetupRequirement
impl Eq for SetupRequirement
impl StructuralPartialEq for SetupRequirement