pub struct TestCase {
pub test_type: TestCaseType,
pub description: String,
pub argument_values: Vec<TestArgumentValue>,
pub expected_outcome: ExpectedOutcome,
}Fields
test_type: TestCaseTypedescription: Stringargument_values: Vec<TestArgumentValue>expected_outcome: ExpectedOutcomeTrait Implementations
Sourceimpl BorshDeserialize for TestCase
impl BorshDeserialize for TestCase
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TestCase
impl BorshSerialize for TestCase
impl Eq for TestCase
impl StructuralPartialEq for TestCase