pub struct TestMetadata {
pub instruction_order: Vec<String>,
pub account_dependencies: Vec<AccountDependency>,
pub pda_init_sequence: Vec<PdaInit>,
pub setup_requirements: Vec<SetupRequirement>,
pub test_cases: Vec<InstructionTestCases>,
}Fields
instruction_order: Vec<String>account_dependencies: Vec<AccountDependency>pda_init_sequence: Vec<PdaInit>setup_requirements: Vec<SetupRequirement>test_cases: Vec<InstructionTestCases>Trait Implementations
Sourceimpl BorshDeserialize for TestMetadata
impl BorshDeserialize for TestMetadata
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TestMetadata
impl BorshSerialize for TestMetadata
Sourceimpl Clone for TestMetadata
impl Clone for TestMetadata
Sourcefn clone(&self) -> TestMetadata
fn clone(&self) -> TestMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TestMetadata
impl Debug for TestMetadata
Sourceimpl PartialEq for TestMetadata
impl PartialEq for TestMetadata
impl Eq for TestMetadata
impl StructuralPartialEq for TestMetadata